% Get the settings for each subject. First cell gets files. Second cell
% lists defaults/settings that are the same for all subjects. Third cell
% lists subject specific settings
%
% Updated Feb. 10, 2015 for subject 56 by WGC wgreycoon@gmail.com
%  


function [ Settings ] = GET_SETTINGS( subj )


%% SUBJECT-SPECIFIC SETTINGS
if subj == 10
    Settings.task                = 'attention';
    Settings.iter                = 1;
elseif subj == 14
    Settings.task                = 'attention'; 
    Settings.iter                = 2;
elseif subj == 15
    Settings.task                = 'attention'; 
    Settings.iter                = 2;
elseif subj == 20
    Settings.task                = 'attention';    
    Settings.iter                = 2;
elseif subj == 38 % works alright
    Settings.task                = 'react';
    Settings.ButtonChannel       = 130;
    Settings.PhotoChannel        = 129;
    Settings.StimChannel         = 132;
    Settings.AudioChannel        = 131;
    Settings.IsRightHemisphere   = 'no';
    % Settings.runs2analyze        = Settings.runs2analyze(end-8:end-4, :);
%     Settings.channels2exclude    = [ 16 21 26 28 53 56 60 84 92 80:256 55 59 64 ]; % 16 is GND. 55, 59, 64 come from Joshua's bad channel detector
%     Settings.channels2exclude    = [ 16 21 26 28 53 56 60 84 92 99:256 55 59 64 ]; % 16 is GND. 55, 59, 64 come from Joshua's bad channel detector
    Settings.channels2exclude    = [16 28 53 55 56 59 64 84 92 99:256]; % 16 is GND. 55, 59, 64 come from Joshua's bad channel detector
elseif subj == 39 % Some channels still obviously bad. This person's reaction times are alarmingly slow anyways...
    Settings.task                = 'react';
    Settings.ButtonChannel       = 66;
    Settings.PhotoChannel        = 65;
    Settings.StimChannel         = 67;
    Settings.AudioChannel        = 68;
    Settings.UseStates           = 1;
    Settings.channels2exclude    = [10 48 65:256 10 49 50 51 52 54 58 59 61 62 63 64]; % 48 is GND, 65:68 have TRIGbox, above that no EcOG. Other bad ones found by Joshua's bad ch detector
    Settings.IsRightHemisphere   = 'no';
    Settings.BrainModelFile      = '\\neuro-server\Lab-Home\Data\ECoG\AMC\SUBJECT038\BrainModel\AMC038_brain.mat'; %TODO: This uses subject 38's brain model
    Settings.runs2analyze        = Settings.runs2analyze(end-6:end-1, :); % The first 5 runs aren't in the runsheet and don't have BCI2000 states, and the 6th doesn't have good button channel signal. The other day 4 runs are ok, but day 5 run 1 has bad button channel
elseif subj == 40 % works alright
    Settings.task                = 'react';
    Settings.ButtonChannel       = 130;
    Settings.PhotoChannel        = 129;
    Settings.StimChannel         = 131;
    Settings.AudioChannel        = 132;
%     Settings.channels2exclude    = [ 22 23 24 14 15 16 6 7 8 80:256 77:79 53:56]; % 53 and 56 are GND on different days...
    Settings.channels2exclude    = [ 16 61 64 72 77:256 53 56]; % 53 and 56 are GND on different days...
    % 77:79 are taken out because there's something wrong with the brain model file, the variable 'tala' only has 76 entries while it usually has 79
%     Settings.runs2analyze        = Settings.runs2analyze(1:end-2, :); 
    Settings.IsRightHemisphere   = 'no';
elseif subj == 41 % works well
    Settings.task                = 'react';
    Settings.ButtonChannel       = 130;
    Settings.PhotoChannel        = 129;
    Settings.StimChannel         = 131;
    Settings.AudioChannel        = 132;
    Settings.channels2exclude    = [ 43 59 75 80:256 ]; % 43 is GND
    Settings.IsRightHemisphere   = 'no';
elseif subj == 45 % works well
    Settings.task                = 'react';
    Settings.ButtonChannel       = 130;
    Settings.PhotoChannel        = 129;
    Settings.StimChannel         = 131;
    Settings.AudioChannel        = 132;
%     Settings.channels2exclude    = [ 52 56:67 80:128 129:132 133:256 ]; % GND on 52, noisy channels 56:67, no ECoG past 79 channels, TRIGbox outs to 129:132, 133:256 contain no signal
    Settings.channels2exclude    = [52 80:256 ]; % GND on 52, noisy channels 56:67, no ECoG past 79 channels, TRIGbox outs to 129:132, 133:256 contain no signal
    Settings.IsRightHemisphere   = 'yes';
elseif subj == 47 % No photo sensor for many trials (might not matter?). TRIGbox channels not in runsheet, these settings don't work. Don't worry about this one, there were very few trials anyways.
    Settings.task                = 'react';
    Settings.ButtonChannel       = 130;
    Settings.PhotoChannel        = 129;
    Settings.StimChannel         = 131;
    Settings.AudioChannel        = 132;
    Settings.channels2exclude    = [ 98 16 56 78 72 73 75 78 80:256 ]; % GND on 98
    Settings.BrainModelFile      = '\\neuro-server\Lab-Home\Data\ECoG\AMC\SUBJECT038\BrainModel\AMC038_brain.mat'; %TODO: This uses subject 38's brain model
    Settings.IsRightHemisphere   = 'no';
elseif subj == 56 % No photo sensor for many trials (might not matter?). TRIGbox channels not in runsheet, these settings don't work. Don't worry about this one, there were very few trials anyways.
    Settings.task                = 'react';
    Settings.ButtonChannel       = 130;
    Settings.PhotoChannel        = 129;
    Settings.StimChannel         = 131;
    Settings.AudioChannel        = 132;
%     Settings.channels2exclude    = [ 28 46 51 71 72 118:256 ]; % GND on 28
    Settings.channels2exclude    = [ 28 118:256 ]; % GND on 28
    Settings.IsRightHemisphere   = 'yes';
elseif subj == 57
    Settings.task                = 'react';
    Settings.ButtonChannel       = 130;
    Settings.PhotoChannel        = 129;
    Settings.StimChannel         = 131;
    Settings.AudioChannel        = 132;
%     Settings.channels2exclude    = [38 50 54 99 115:256];  
    Settings.channels2exclude    = [38 50 54 99 115:256];
    Settings.IsRightHemisphere   = 'no';
elseif subj == 58
    Settings.task                = 'react';
    Settings.ButtonChannel       = 130;
    Settings.PhotoChannel        = 129;
    Settings.StimChannel         = 131;
    Settings.AudioChannel        = 132;
    Settings.channels2exclude    = [64 93 94 99:256]; 
    Settings.IsRightHemisphere   = 'yes';   
% elseif subj == 62
%     Settings.task                = 'react';
%     Settings.ButtonChannel       = ;
%     Settings.PhotoChannel        = ;
%     Settings.StimChannel         = ;
%     Settings.AudioChannel        = ;
%     Settings.channels2exclude    = []; 
%     Settings.IsRightHemisphere   = '';  
    
% elseif subj == 71
%     Settings.task                = 'react';
%     Settings.ButtonChannel       = 194 ;
%     Settings.PhotoChannel        = [];
%     Settings.StimChannel         = [];
%      Settings.AudioChannel        = 196;
%      Settings.channels2exclude = [31 138:256];
%      Settings.IsRightHemisphere   = 'yes';
%      Settings.UseStates           = 1;

elseif subj == 71
    Settings.task = 'react';
    Settings.ButtonChannel = 194;
    Settings.PhotoChannel = 193;
    Settings.StimChannel = 195;
    Settings.AudioChannel = 196;
    Settings.channels2exclude = [37 139:256];
    Settings.IsRightHemisphere   = 'yes';
else
    throw(MException('GetSettings:UnknownSubject', 'Requested settings for an unknown subject'));
end


%% TASK-SPECIFIC SETTINGS
Settings.runs2analyze = [];

if strcmpi(Settings.task, 'react')
    % Runs to analyze
    root = 'data/RT';
    days = dir(sprintf('%s/SUBJECT%03d/BCI2000/data/DAY*', root, subj));
    for i = 1:size(days, 1)
        nameroot = sprintf('%s/SUBJECT%03d/BCI2000/data/%s/react_task/ECOG001', root, subj, days(i).name);
        filenames = dir(sprintf('%s/ECOG*.dat', nameroot));
        for j = 1:size(filenames)
            if (size(strfind(filenames(j).name, 'wrong')) == 0)
                Settings.runs2analyze = [Settings.runs2analyze; sprintf('%s/%s', nameroot, filenames(j).name)];
            end
        end
    end

    % Other settings
    Settings.TimeBeforeStimOn                    = 1000                    ;    % time in milliseconds to start gathering signal, relative to stimulus onset
    Settings.TimeAfterStimOn                     = 1000                    ;    % time in milliseconds to end analysis, relative to stimulus onset
    Settings.BaselineWindow                      = 1000                    ;    % time in milliseconds to use as pre-stimulus baseline
    Settings.AnalysisWindow                      = 1000                    ;    % time in milliseconds to analyze after stimulus onset
    Settings.BrainModelFile                      = sprintf('%s/SUBJECT%03d/BrainModel/AMC%03d_brain.mat', root, subj, subj);
    Settings.SurfPlotTimeWindow                  = 1000                    ;    % time in milliseconds to plot on surf plots
    Settings.UseNewDetector                      = true                    ;
    
elseif strcmpi(Settings.task, 'attention')
    % Runs to analyze
    root = 'data/AT';
    nameroot = sprintf('%s/data files/SUBJECT%03d/ECOG001001', root, subj);
    filenames = dir(sprintf('%s/data files/SUBJECT%03d/ECOG001001/*.dat', root, subj));
    for j = 1:size(filenames,1)
        Settings.runs2analyze = [Settings.runs2analyze; sprintf('%s/%s', nameroot, filenames(j).name)];
    end

    % Other settings
    Settings.SubjVarsFile = sprintf('%s/subject vars/SUBJECT%03d_vars.mat', root, subj);
    Settings.TimeBeforeCueChange                 = 3000                    ;% <====    % time in milliseconds to start gathering signal, relative to cue change
    Settings.TimeAfterCueChange                  = 3000                    ;% <====    % time in milliseconds to end analysis, relative to cue change
    Settings.BaselineWindow                      = 3000                    ;
    Settings.AnalysisWindow                      = 3000                    ;
    Settings.BrainModelFile                      = sprintf('%s/brain models/AMC_%03d_brain.mat', root, subj);
    Settings.SurfPlotTimeWindow                  = 1500                    ;    % time in milliseconds to plot on surf plots
    Settings.UseNewDetector                      = false                   ;
end


%% DEFAULT SETTINGS

% These ones from the react task, or both:
Settings.UseMatlabPool                       = true                        ;
Settings.FirstRun                            = 1                           ;
Settings.ExportNewBrainFig                   = 'yes'                       ;
Settings.IsRightHemisphere                   = 'no'                        ;

Settings.KernelSmoothing                     = false                       ;    % do signal smoothing with a gaussian kernel
Settings.KernelSigma                         = 2                           ;    % sigma for kernel design
Settings.KernelSize                          = 40                          ;    % kernel size

Settings.Subject                             = subj                        ;
Settings.ButtonPressThreshold                = 500                         ;    %TODO: Might want to lower this to 30 to catch small spikes
Settings.PhotoThreshold                      = 1000                        ;
Settings.StimThreshold                       = 1000                        ;
Settings.AudioThreshold                      = 1000                        ;
Settings.UseStates                           = 0                           ;    % 1 = use BCI2000 states, 0 = use TRIGbox for determining stimulus times
Settings.StimStatsMaxLag                     = 150                         ;    % Range of stimulus stats histograms
Settings.StimStatsBinSize                    = 1                           ;    % ms
Settings.StimStatsNumBins                    = 20                          ;    % number of bins for histogram of time tags b/w sensors and BCI2000 states
Settings.HiPass                              = 70                          ;    
Settings.LowPass                             = 170                         ;    
Settings.NotchFilter                         = [117 123]                   ;    % notch filter parameters (set to [-1 -1] for no notch filtering)
Settings.ApplyCar                            = 1                           ;    % 1 = yes    0 = no
Settings.AlphaHiPass                         = 8                           ;
Settings.AlphaLoPass                         = 12                          ;
Settings.AlphaBiasRecon                      = 0                           ;    % Use pushdown bias reconstruction for alpha? 1 = yes, 0 = no
Settings.CanonGammaHiPass                    = 40                          ;
Settings.CanonGammaLoPass                    = 70                          ;
Settings.CanonGammaNotch                     = [58 62]                     ;
Settings.ResampleFrequency                   = 400                         ;    % frequency in Hz to resample after bandpass filtering; set equal to original sampling frequency for no resampling
Settings.BaselineType                        = 'all'                       ;    % specify baseline derived from single trials ('single') or from all trials ('all')
Settings.RxBoundOn                           = 'no'                        ;    % if bound is on ('yes'), detector stops seeking at time of button press...
Settings.SNRBinsize                          = 50                          ;    % # samples in each SNR bin
Settings.ElecSelPrunePval                    = .01                         ;    % Significance required for binomial test pval
Settings.falseHitsMax                        = 1.0                         ;    % (Percent/100). Maximum number of false hits allowed when picking best detector parameters 
Settings.MakeFigs                            = 'yes'                       ;
Settings.ShowAxes                            = 'no'                        ;
Settings.CLim                                = [-6 6]                      ;
Settings.SurfPlotYLabel                      = 'Gamma Power (70 - 170 Hz) ';
Settings.OverlaidPlotSize                    = 20                          ;    % half the width/height of overlaid plots over the 2d brain image
Settings.OverlaidPlotBorderSize              = 1                           ;    % in points
Settings.OverlaidPlotColor                   = 'black'                     ;    % Border for task electrode plots on brain, any Matlab color specifier (eg. 'b', 'blue', or [0 0 1])
Settings.OverlaidPlotColorTwo                = 'yellow'                    ;    % For values of Settings.ColorBy that require two colors
Settings.ColorBy                             = 'active network'            ;    % Only "active network" allowed here. See the end of ANLAYZE.m for examples of how to use this
Settings.Offset                              = 0                           ;    % Offset in milliseconds for figure plotting (relative to time of stim onset)
Settings.MasterFigSuffix                     = '_gamma'                    ;
Settings.PlotOnsets                          = false                       ;
Settings.PlotBehaviorLine                    = 0                           ;    % 1 = yes, 0 = no
Settings.ZthresholdRange                     = 2:0.1:6                     ;    % threshold for z-scores to determine activity onset times
Settings.ZpThreshold                         = 0.01                        ;    % significance cutoff for corrcoef (onset times, rx_times)
Settings.DoFadedOutCmap                      = 0                           ;    % 1 = yes, 0 = no
Settings.FadeOutFromCmap                     = [-1.5 1.5]                  ;    % part of colormap to fade out (units are currently in z-scores)
Settings.Color2FadeTo                        = [1.0 1.0 1.0]               ;    % RGB values bound from 0 to 1

% These ones from the attention task
Settings.FindLaterality                      = 'yes'                       ;
Settings.DoLaterality                        = 'no'                        ;
Settings.IpsiContra                          = 'contra'                    ;
Settings.PValThreshForSpreadDetection        = 0.01                        ;



%end

