%% Preprocessing a brain model

clear;
close all;

addpath(genpath(cd))

brainfile = 'DEMOsubj_brain.mat';
load(brainfile);

activations = ones(size(strct.electrodes,1),1);

strct.activations = activations;

%make the model coarser:
cortexcoarser = coarserModel(cortex, 10000);

%*Approach A*
%compute the convex hull:
cortexHull = hullModel(cortexcoarser);
%this deprives the brain model of its sulci

%% Projecting the electrodes
%project the electrodes onto the surface of the brain:
normdist = 55;
%(using the normal vector projection; the normal vector is computed by
%averaging the normal vectors at the electrode distance normdist and less;
%see also |projectElectrodes| for a more thorough information on its arguments)

[ strct ] = projectElectrodes( cortexHull, strct, normdist);

%% Visualizing the activations
%Set what you want to see:
%(please consult |activateBrain| for further information on the following structures)

viewstruct.what2view    = {'brain'};
viewstruct.material     = 'dull';
viewstruct.enablelight  = 1;
viewstruct.enableaxis   = 0;
viewstruct.lightingtype = 'gouraud';

side = mean(strct.electrodes);
if side(1) > 0
    param.electrodes_pos = 'right';
else
    param.electrodes_pos = 'left';
end

if strcmp(param.electrodes_pos,'right')
    viewstruct.viewvect     = [90, 0];
    viewstruct.lightpos     = [150, 0, 0];
elseif strcmp(param.electrodes_pos,'left')
    viewstruct.viewvect     = [270, 0];
    viewstruct.lightpos     = [-150, 0, 0];
end

%and how you want to see it:
cmapstruct.cmap = colormap('Winter'); 
cmapstruct.basecol = [0.7, 0.7, 0.7];
cmapstruct.fading = true;
cmapstruct.ixg2 = floor(length(cmapstruct.cmap) * 0.15);
cmapstruct.ixg1 = -cmapstruct.ixg2;
cmapstruct.enablecolormap = true;
cmapstruct.enablecolorbar = false;


%Run |activateBrain|:
%NOTE:
%Do not forget to use the same brain model as the one used for the
%precomputation of the contributions (that is, the fine one). Also,
%use the subj that is the output of |projectElectrodes|).
ix = 1;
cmapstruct.cmin = 0.25;
cmapstruct.cmax = 1.5;
set(gca, 'Color', 'none'); set(gcf, 'Color', 'w'); grid off;

activateBrain( cortex, [], strct, ix, cmapstruct, viewstruct );


plotSpheres(strct.electrodes, 'k')
plotElNums(strct.electrodes, 1:size(strct.electrodes,1), 12)
    
ax = gca;               % get the current axis
ax.Clipping = 'off';    % turn clipping off
