
function [h, substruc, val] = isfield_recursive(s, f)

% this function search all the nested structures within any given structure
% array and find the number of specified fields

% input:
% s : the strucutre which we want to fully search in all levels
% f : the name of the target field

% output:
% h : the number of founded fields
% substruc: the locaiton of the founded fields
% val : the value of the founded fields

if isstruct(s) && ~isempty(s)
    
    fields = fieldnames(s);
    
    for ii = 1 : length(fields)
        
        field_name = fields{ii,1};
        
        if isfield(s.field_name, f)
            
            h = h + 1;
            val.h = s.field_name.f;
            substruc.h = fprintf('%s.%s.%s',s,field_name,f);
            
        else
            
            s = s.field_name;
            [h, substruc, val] = isfield_recursive(s, f);
            
        end
        
    end
    
end





% ISSUBFIELD tests for the presence of a field in a structure just like the standard
% Matlab ISFIELD function, except that you can also specify nested fields
% using a '.' in the fieldname. The nesting can be arbitrary deep.
%
% Use as
%   f = issubfield(s, 'fieldname')
% or as
%   f = issubfield(s, 'fieldname.subfieldname')
%
% This function returns true if the field is present and false if the field
% is not present.
%
% See also ISFIELD, GETSUBFIELD, SETSUBFIELD

% Copyright (C) 2005-2013, Robert Oostenveld
%
% This file is part of FieldTrip, see http://www.fieldtriptoolbox.org
% for the documentation and details.
%
%    FieldTrip is free software: you can redistribute it and/or modify
%    it under the terms of the GNU General Public License as published by
%    the Free Software Foundation, either version 3 of the License, or
%    (at your option) any later version.
%
%    FieldTrip is distributed in the hope that it will be useful,
%    but WITHOUT ANY WARRANTY; without even the implied warranty of
%    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
%    GNU General Public License for more details.
%
%    You should have received a copy of the GNU General Public License
%    along with FieldTrip. If not, see <http://www.gnu.org/licenses/>.
%
% $Id$

%try
%  getsubfield(s, f);    % if this works, then the subfield must be present
%  r = true;
%catch
%  r = false;                % apparently the subfield is not present
%end

if isempty(f) || isempty(s)
    r = false;
else
    t = textscan(f,'%s','delimiter','.');
    t = t{1};
    r = true;
    for k = 1:numel(t)
        if isfield(s, t{k})
            s = s.(t{k});
        else
            r = false;
            return;
        end
    end
end